@@ -33,7 +33,7 @@ static cTimeMs __time;
 #define time_ms() ((int)__time.Elapsed())
 #endif
 
-#ifdef DEBUG
+#if !defined(NO_DEBUG) && defined(DEBUG)
 #define d(x) { (x); }
 #else
 #define d(x) ; 
