@@ -28,6 +28,7 @@ const tI18nPhrase Phrases[] = {
 /*
  * French     translations provided by Maxime Guilbot <maxime.guilbot@orange.fr>
  *               additions provided by Pierre-Henri Beguin <ph.beguin@free.fr>
+ *               additions provided by Jerome Rousset <zekje@hotmail.com>
  * Slovenian  translations provided by Matjaz Thaler <matjaz.thaler@guest.arnes.si>
  * Greek      translations provided by Dimitrios Dimitrakos <mail@dimitrios.de>
  * Swedish    translations provided by Jan Ekholm <chakie@infa.abo.fi>
@@ -283,7 +284,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "", // TODO
+    "Cacher l entre du menu",
     "", // TODO
     "Piilota valinta pvalikosta",
     "", // TODO
@@ -326,7 +327,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "", // TODO
+    "Lecteur multiformats",
     "", // TODO
     "Monipuolinen audiosoitin",
     "", // TODO
@@ -786,7 +787,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "Erreur de chargement de la liste!",
+    "Erreur de chargement de la playlist!",
     "", // TODO
     "Soittolistan avaaminen eponnistui!",
     "", // TODO
@@ -1206,7 +1207,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "Prcision",
+    "Bitrate",
     "", // TODO
     "Bittinopeus",
     "", // TODO
@@ -1266,7 +1267,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "", // TODO
+    "Mode de sortie audio",
     "", // TODO
     "nen ulostulomoodi",
     "", // TODO
@@ -1346,7 +1347,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "Choisir",
+    "Lisser",
     "", // TODO
     "ditteroitu",
     "", // TODO
@@ -1366,7 +1367,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "",
+    "Scan en tache de fond",
     "", // TODO
     "Taustaskannaus",
     "", // TODO
@@ -1386,7 +1387,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "",
+    "Seulement ID3",
     "", // TODO
     "vain ID3",
     "", // TODO
@@ -1406,7 +1407,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "",
+    "ID3 et niveau",
     "", // TODO
     "ID3 & taso",
     "", // TODO
@@ -1506,7 +1507,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "deactiver",
+    "dsactiver",
     "", // TODO
     "pois",
     "", // TODO
@@ -1706,7 +1707,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "Imagen",
+    "Live",
     "", // TODO
     "live",
     "", // TODO
@@ -1726,7 +1727,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "",
+    "Images",
     "", // TODO
     "kansikuva",
     "", // TODO
@@ -1766,7 +1767,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "Listes de lecture",
+    "Playlists",
     "", // TODO
     "soittolistat",
     "", // TODO
@@ -1846,7 +1847,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "", // TODO
+    "Stopper le lecteur  la fin de la liste",
     "", // TODO
     "Keskeyt soittolistan loputtua",
     "", // TODO
@@ -1866,7 +1867,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "", // TODO
+    "Affichage relecture",
     "", // TODO
     "Toistotilan nyttmoodi",
     "", // TODO
@@ -1886,7 +1887,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "", // TODO
+    "Classique",
     "", // TODO
     "klassinen",
     "", // TODO
@@ -1899,7 +1900,6 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10302
     "",
 #endif
-
   },
   { "via skin",
     "ber Skin",
@@ -1907,7 +1907,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "", // TODO
+    "Par skin",
     "", // TODO
     "ulkoasun mukaan",
     "", // TODO
@@ -1920,7 +1920,26 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10302
     " ",
 #endif
-
+  },
+  { "Setup.MP3$Keep selection menu",
+    "Auswahlmenu geffnet lassen",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "",
+    "", // TODO
+    "Pid valintaikkunaa auki",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+#if VDRVERSNUM >= 10302
+    "",
+#endif
   },
 
 // start of MPlayer specific phrases
@@ -1951,7 +1970,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "", // TODO
+    "Lecture par MPlayer",
     "", // TODO
     "MPlayeriin perustuva mediasoitin",
     "", // TODO
@@ -2064,7 +2083,26 @@ const tI18nPhrase Phrases[] = {
 #if VDRVERSNUM >= 10302
     "",
 #endif
-
+  },
+  { "Setup.MPlayer$OSD position",
+    "OSD Position",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "",
+    "", // TODO
+    "Kuvaruutunytn sijainti",
+    "", // TODO
+    "", 
+    "", // TODO
+    "",
+    "", // TODO
+    "", // TODO
+    "",
+#if VDRVERSNUM >= 10302
+    "",
+#endif
   },
   { "Setup.MPlayer$Resume mode",
     "Modus fr Wiederaufnahme",
@@ -2072,7 +2110,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "",
+    "Reprise",
     "", // TODO
     "Resume-toiminto",
     "", // TODO
@@ -2092,7 +2130,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "",
+    "Local en premier",
     "", // TODO
     "paikallinen",
     "", // TODO
@@ -2112,7 +2150,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "",
+    "Global seulement",
     "", // TODO
     "globaali",
     "", // TODO
@@ -2124,6 +2162,26 @@ const tI18nPhrase Phrases[] = {
     "",
 #if VDRVERSNUM >= 10302
     "",
+#endif
+  },
+  { "Setup.MPlayer$Slave command key",
+    "Slave Kommando Taste",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "",
+    "", // TODO
+    "Orjakomento nppimelle",
+    "", // TODO
+    "", 
+    "", // TODO
+    "",
+    "", // TODO
+    "", // TODO
+    "",
+#if VDRVERSNUM >= 10302
+    "",
 #endif
   },
   { "MPlayer Audio ID",
@@ -2132,7 +2190,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "",
+    "Mplayer piste audio",
     "", // TODO
     "MPlayerin niraidan valinta",
     "", // TODO
@@ -2152,7 +2210,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-    "",
+    "Canal audio",
     "", // TODO
     "niraidan ID",
     "", // TODO
