@@ -259,7 +259,11 @@ cMP3Control::cMP3Control(void)
 #else
   statusInterfaceOpen=false;
 #endif
+#if VDRVERSNUM >= 10338
+  cStatus::MsgReplaying(this,"MP3",0,true);
+#else
   cStatus::MsgReplaying(this,"MP3");
+#endif
 }
 
 cMP3Control::~cMP3Control()
@@ -271,7 +275,11 @@ cMP3Control::~cMP3Control()
 
 void cMP3Control::Stop(void)
 {
+#if VDRVERSNUM >= 10338
+  cStatus::MsgReplaying(this,0,0,false);
+#else
   cStatus::MsgReplaying(this,0);
+#endif
   delete player; player=0;
   mgr->Halt();
   mgr->Flush(); //XXX remove later
@@ -490,7 +498,11 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
       if(changed || mode->Loop!=lastMode->Loop || mode->Shuffle!=lastMode->Shuffle) {
         snprintf(buf,sizeof(buf),mode->Artist[0]?"[%c%c] (%d/%d) %s - %s":"[%c%c] (%d/%d) %s",
                   mode->Loop?'L':'.',mode->Shuffle?'S':'.',mode->Num,mode->MaxNum,mode->Title,mode->Artist);
+#if VDRVERSNUM >= 10338
+        cStatus::MsgReplaying(this,buf,mode->Filename[0]?mode->Filename:0,true);
+#else
         cStatus::MsgReplaying(this,buf);
+#endif
         }
       }
 
@@ -500,7 +512,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
 #if VDRVERSNUM >= 10307
       if(MP3Setup.ReplayDisplay) {
         if(!statusActive) {
-          disp->SetProgress(index,total);
+          if(total>0) disp->SetProgress(index,total);
           disp->SetCurrent(IndexToHMSF(index));
           disp->SetTotal(IndexToHMSF(total));
           bool Play, Forward;
@@ -793,6 +805,14 @@ eOSState cMP3Control::ProcessKey(eKeys Key)
       Hide();
       Stop();
       return osEnd;
+    case kBack:
+      Hide();
+#if VDRVERSNUM >= 10332
+      cRemote::CallPlugin(i18n_name);
+      return osBack;
+#else
+      return osEnd;
+#endif
 
     case k0 ... k9:
       number=number*10+Key-k0;
@@ -839,8 +859,6 @@ eOSState cMP3Control::ProcessKey(eKeys Key)
       oktime=time(0)+MULTI_TIMEOUT;
       ShowStatus(true);
       break;
-    case kBack:
-      Hide(); return osEnd; //XXX osMP3;
     default:
       return osUnknown;
     }
