@@ -37,6 +37,9 @@
 #if VDRVERSNUM >= 10307
 #include <vdr/skins.h>
 #endif
+#if VDRVERSNUM >= 10332
+#include <vdr/remote.h>
+#endif
 
 #if VDRVERSNUM > 10307
 #include <vdr/menu.h>
@@ -141,6 +144,7 @@ private:
   void DisplayAtBottom(const char *s);
   void ShowProgress(void);
   void ShowMode(void);
+  void ShowTitle(void);
   void Jump(void);
   void JumpProcess(eKeys Key);
   void JumpDisplay(void);
@@ -160,7 +164,6 @@ cMPlayerControl::cMPlayerControl(void)
 :cControl(player=new cMPlayerPlayer(file,rewind))
 {
   visible=modeOnly=jumpactive=haveBeauty=false;
-  cStatus::MsgReplaying(this,file->Path());
 #if VDRVERSNUM >= 10307
   display=0;
 #else
@@ -182,12 +185,17 @@ cMPlayerControl::cMPlayerControl(void)
   d(printf("mplayer: beauty patch %sdetected\n",haveBeauty?"":"NOT "))
 #endif //HAVE_BEAUTYPATCH
 #endif //VDRVERSNUM >= 10307
+  ShowTitle();
 }
 
 cMPlayerControl::~cMPlayerControl()
 {
   Stop();
+#if VDRVERSNUM >= 10338
+  cStatus::MsgReplaying(this,0,0,false);
+#else
   cStatus::MsgReplaying(this, NULL);
+#endif
 }
 
 void cMPlayerControl::SetFile(const cFileObj *File, bool Rewind)
@@ -237,6 +245,39 @@ void cMPlayerControl::DisplayAtBottom(const char *s)
 #endif
 }
 
+void cMPlayerControl::ShowTitle(void)
+{
+  const char *name=0;
+  bool release=true;
+  if(player) name=player->GetCurrentName();
+  if(!name) {
+    name=file->Path();
+    release=false;
+    }
+  if(name) {
+#if VDRVERSNUM >= 10338
+    cStatus::MsgReplaying(this,name,0,true);
+#else
+    cStatus::MsgReplaying(this,name);
+#endif
+    if(visible) {
+#if VDRVERSNUM >= 10307
+      if(display) display->SetTitle(name);
+#else
+      int n=strlen(name);
+      if(n>Width()) {
+        n=n-Width()+4; if(n<0) n=0;
+        char str[72];
+        snprintf(str,sizeof(str),"... %s",name+n);
+        Interface->Write(0,0,str);
+        }
+      else Interface->Write(0,0,name);
+#endif
+      }
+    }
+  if(release) free((void *)name);
+}
+
 void cMPlayerControl::ShowProgress(void)
 {
   int Current, Total;
@@ -252,43 +293,29 @@ void cMPlayerControl::ShowProgress(void)
       if(MPlayerSetup.OsdPos>0) Interface->Fill(0,3,Interface->Width(),MPlayerSetup.OsdPos,clrTransparent);
 #endif
       needsFastResponse=visible=true; modeOnly=false;
-      if(file) {
-#if VDRVERSNUM >= 10307
-        display->SetTitle(file->Path());
-#else
-        const char *fileName=file->Path();
-        int n=strlen(fileName);
-        if(n>Width()) {
-          n=n-Width()+4; if(n<0) n=0;
-          char str[72];
-          snprintf(str,sizeof(str),"... %s",fileName+n);
-          Interface->Write(0,0,str);
-          }
-        else Interface->Write(0,0,fileName);
-#endif
-        }
       lastCurrent=lastTotal=-1;
       flush=true;
       }
 
-    if(Current!=lastCurrent) {
+    if(abs(Current-lastCurrent)>12) {
 #if VDRVERSNUM >= 10307
-       display->SetProgress(Current, Total);
-       display->SetCurrent(IndexToHMSF(Current));
-       display->SetTotal(IndexToHMSF(Total));
-       bool Play, Forward;
-       int Speed;
-       if(GetReplayMode(Play,Forward,Speed)) 
-         display->SetMode(Play, Forward, Speed);
+      if(Total>0) display->SetProgress(Current, Total);
+      display->SetCurrent(IndexToHMSF(Current));
+      display->SetTotal(IndexToHMSF(Total));
+      bool Play, Forward;
+      int Speed;
+      if(GetReplayMode(Play,Forward,Speed)) 
+        display->SetMode(Play, Forward, Speed);
 #else
-       cProgressBar ProgressBar(Width() * cOsd::CellWidth(), cOsd::LineHeight(), Current, Total);
-       Interface->SetBitmap(0, cOsd::LineHeight(), ProgressBar);
-       Interface->Write(0,2,IndexToHMSF(Current));
-       Interface->Write(-7,2,IndexToHMSF(Total));
+      cProgressBar ProgressBar(Width() * cOsd::CellWidth(), cOsd::LineHeight(), Current, Total);
+      Interface->SetBitmap(0, cOsd::LineHeight(), ProgressBar);
+      Interface->Write(0,2,IndexToHMSF(Current));
+      Interface->Write(-7,2,IndexToHMSF(Total));
 #endif
-       flush=true;
-       lastCurrent=Current; lastTotal=Total;
-       }
+      ShowTitle();
+      flush=true;
+      lastCurrent=Current; lastTotal=Total;
+      }
     if(flush) 
 #if VDRVERSNUM >= 10307
       Skins.Flush();
@@ -451,6 +478,7 @@ eOSState cMPlayerControl::ProcessKey(eKeys Key)
         else ShowProgress();
         }
       }
+    else ShowTitle();
 
     if(jumpactive && Key != kNone) {
       JumpProcess(Key);
@@ -486,9 +514,14 @@ eOSState cMPlayerControl::ProcessKey(eKeys Key)
   //    case kYellow|k_Repeat:
   //    case kYellow:  player->SkipNext(); break;
 
+      case kBack:
+#if VDRVERSNUM >= 10332
+                     Hide();
+                     cRemote::CallPlugin(i18n_name);
+                     return osBack;
+#endif
       case kStop:
-      case kBlue:
-      case kBack:    Hide(); Stop(); return osEnd;
+      case kBlue:    Hide(); Stop(); return osEnd;
 
       default:
         DoShowMode = false;
