@@ -42,18 +42,20 @@
 #include "decoder.h"
 #include "decoder-core.h"
 
+#ifndef NO_DEBUG
 //#define DEBUG_MODE      // debug playmode changes
 #define DEBUG_BGR       // debug backround scan thread
 #define DEBUG_DELAY 300 // debug write/decode delays
 //#define ACC_DUMP        // dump limiter lookup table to /tmp/limiter
+#endif
 
-#ifdef DEBUG_MODE
+#if !defined(NO_DEBUG) && defined(DEBUG_MODE)
 #define dm(x) { (x); }
 #else
 #define dm(x) ; 
 #endif
 
-#ifdef DEBUG_BGR
+#if !defined(NO_DEBUG) && defined(DEBUG_BGR)
 #define db(x) { (x); }
 #else
 #define db(x) ; 
@@ -950,6 +952,7 @@ bool cPlayManager::Info(int num, cMP3PlayInfo *pi)
   bool res=false;
   if(s) {
     strn0cpy(pi->Title,s->Name(),sizeof(pi->Title));
+    strn0cpy(pi->Filename,s->FullPath(),sizeof(pi->Filename));
     cSongInfo *si=s->Info(false);
     if(si && si->HasInfo()) {
       static char *modestr[] = { "Mono","Dual","Joint-Stereo","Stereo" };
@@ -1160,6 +1163,8 @@ public:
   virtual cFrame *MakeFrame(unsigned int & Samples, const mad_fixed_t **Data, int index, int sr)=0;
   virtual int Output(const unsigned char *Data, int Len, bool SOF)=0;
   virtual bool Poll(void)=0;
+  virtual void Play(void)=0;
+  virtual void Pause(void)=0;
 #ifdef DEBUG
   virtual void Stats(void);
 #endif
@@ -1213,6 +1218,8 @@ public:
   virtual cFrame *MakeFrame(unsigned int & Samples, const mad_fixed_t **Data, int index, int sr);
   virtual int Output(const unsigned char *Data, int Len, bool SOF);
   virtual bool Poll(void);
+  virtual void Play(void);
+  virtual void Pause(void);
   };
 
 cOutputDvb::cOutputDvb(cMP3Player *Player)
@@ -1352,6 +1359,20 @@ bool cOutputDvb::Poll(void)
   return player->DevicePoll(poll,500);
 }
 
+void cOutputDvb::Play(void)
+{
+#ifndef BROKEN_PCM
+  player->DevicePlay();
+#endif
+}
+
+void cOutputDvb::Pause(void)
+{
+#ifndef BROKEN_PCM
+  player->DeviceFreeze();
+#endif
+}
+
 // --- cOutputOss --------------------------------------------------------------
 
 #ifdef WITH_OSS
@@ -1374,6 +1395,8 @@ public:
   virtual cFrame *MakeFrame(unsigned int & Samples, const mad_fixed_t **Data, int index, int sr);
   virtual int Output(const unsigned char *Data, int Len, bool SOF);
   virtual bool Poll(void);
+  virtual void Play(void);
+  virtual void Pause(void);
   };
 
 cOutputOss::cOutputOss(cMP3Player *Player)
@@ -1391,7 +1414,7 @@ cOutputOss::~cOutputOss()
 void cOutputOss::Init(void)
 {
   if(fd<0) {
-    fd=open(dspdevice,O_WRONLY);
+    fd=open(dspdevice,O_WRONLY|O_NONBLOCK);
     if(fd>=0) poll.Add(fd,true);
     else esyslog("ERROR: Cannot open dsp device '%s': %s!",dspdevice,strerror(errno));
     }
@@ -1453,15 +1476,19 @@ cFrame *cOutputOss::MakeFrame(unsigned int & Samples, const mad_fixed_t **Data,
 
 int cOutputOss::Output(const unsigned char *Data, int Len, bool SOF)
 {
-  int n=0;
-  if(SOF) {
-    struct FrameHeader *fh=(struct FrameHeader *)Data;
-    if(fh->samplerate!=outSr) Reset(fh->samplerate);
-    n=FHS;
-    Data+=n; Len-=n;
+  if(fd>=0) {
+    int n=0;
+    if(SOF) {
+      struct FrameHeader *fh=(struct FrameHeader *)Data;
+      if(fh->samplerate!=outSr) Reset(fh->samplerate);
+      n=FHS;
+      Data+=n; Len-=n;
+      }
+    int r=write(fd,Data,Len);
+    if(r<0 && !FATALERRNO) r=0;
+    if(r>=0) return n+r;
     }
-  int r=fd>=0 ? write(fd,Data,Len) : -1;
-  return (r>=0 ? r+n : -1);
+  return -1;
 }
 
 bool cOutputOss::Poll(void)
@@ -1469,16 +1496,25 @@ bool cOutputOss::Poll(void)
   return fd>=0 ? poll.Poll(500) : false;
 }
 
+void cOutputOss::Play(void)
+{
+}
+
+void cOutputOss::Pause(void)
+{
+  CHECK(ioctl(fd,SNDCTL_DSP_POST,0));
+}
+
 #endif
 
 // --- cMP3Player --------------------------------------------------------------
 
 cMP3Player::cMP3Player()
-:cPlayer(MP3Setup.BackgrMode==1 ? (MP3Setup.AudioOutMode==AUDIOOUTMODE_DVB ? pmAudioOnly:pmNone) : pmAudioOnlyBlack)
+:cPlayer(MP3Setup.BackgrMode==1 ? pmAudioOnly : pmAudioOnlyBlack)
 {
   active=true; started=false; isStream=false;
   ringBuffer=new cRingBufferFrame(MP3BUFSIZE);
-  rframe=0; pframe=0; decoder=0;
+  rframe=0; pframe=0; decoder=0; output=0;
   playMode=pmStartup; state=msStop;
   playindex=total=0;
 }
@@ -1561,12 +1597,12 @@ void cMP3Player::Action(void)
   state=msStop;
   SetPlayMode(pmStopped);
 
-  cOutput *out=0;
+  delete output; output=0;
 #ifdef WITH_OSS
-  if(MP3Setup.AudioOutMode==AUDIOOUTMODE_OSS) out=new cOutputOss(this);
+  if(MP3Setup.AudioOutMode==AUDIOOUTMODE_OSS) output=new cOutputOss(this);
 #endif
-  if(MP3Setup.AudioOutMode==AUDIOOUTMODE_DVB) out=new cOutputDvb(this);
-  if(!out) {
+  if(MP3Setup.AudioOutMode==AUDIOOUTMODE_DVB) output=new cOutputDvb(this);
+  if(!output) {
     d(printf("mp3: audiooutmode mismatch or no output driver\n"))
     esyslog("ERROR: no audio output driver. balling out");
     goto abort;
@@ -1579,7 +1615,7 @@ void cMP3Player::Action(void)
     if(now>=beat) {
       int avail=ringBuffer->Available();
       printf("mp3: heartbeat buffer=%d now=%d\n",avail,now&4095);
-      //out->Stats(); if(haslevel) norm.Stats();
+      //output->Stats(); if(haslevel) norm.Stats();
       beat=now+(avail>(MP3BUFSIZE*10/100) ? (avail<(MP3BUFSIZE*50/100) ? 2 : 20) : 1);
       }
     }
@@ -1620,7 +1656,7 @@ next:
       lastwrite=now;
       }
 #endif
-      int w=out->Output(p,pc,SOF);
+      int w=output->Output(p,pc,SOF);
       if(w>0) {
         p+=w; pc-=w;
         if(pc<=0) {
@@ -1664,7 +1700,7 @@ next:
                   total=SecondsToFrames(si->Total);
                 }
               d(printf("mp3: isStream=%d levelgood=%d haslevel=%d\n",isStream,levelgood,haslevel))
-              out->Init();
+              output->Init();
               level.Init();
               if(MP3Setup.BackgrMode==2) imageValid=false;
               state=msDecode;
@@ -1738,7 +1774,7 @@ next:
           data[0]=pcm->samples[0];
           data[1]=pcm->channels>1 ? pcm->samples[1]:0;
 
-          dvbSampleRate=out->SampleRate(pcm->samplerate);
+          dvbSampleRate=output->SampleRate(pcm->samplerate);
           if(dvbSampleRate!=pcm->samplerate) {
             if(resample[0].SetInputRate(pcm->samplerate,dvbSampleRate)) {
               nsamples[0]=resample[0].ResampleBlock(nsamples[0],data[0]);
@@ -1752,7 +1788,7 @@ next:
           state=msOutput;
           break;
         case msOutput:
-          if(nsamples[0]>0) rframe=out->MakeFrame(nsamples[0],data,readindex,dvbSampleRate);
+          if(nsamples[0]>0) rframe=output->MakeFrame(nsamples[0],data,readindex,dvbSampleRate);
           else state=msDecode;
           break;
         case msError:
@@ -1767,7 +1803,7 @@ next:
           mgr->Release(); playing=0; imageValid=true;
           levelgood=false;
 #ifdef DEBUG
-          out->Stats(); if(haslevel) norm.Stats();
+          output->Stats(); if(haslevel) norm.Stats();
 #endif
           if(state==msStop) SetPlayMode(pmStopped);
           if(state==msRestart) state=msStart;
@@ -1798,7 +1834,7 @@ next:
 
     if((rframe || state==msWait) && pframe) {
       mgr->Throttle(false);
-      out->Poll();
+      output->Poll();
       }
     else if(playMode!=pmPlay) {
       mgr->Throttle(false);
@@ -1821,7 +1857,7 @@ next:
 abort:
   Lock();
   delete rframe;
-  delete out;
+  delete output; output=0;
   if(decoder) { decoder->Stop(); decoder=0; }
   mgr->Release(); playing=0;
   SetPlayMode(pmStopped);
@@ -1859,9 +1895,7 @@ void cMP3Player::Pause(void)
   if(playMode==pmPaused) Play();
   else if(playMode==pmPlay && !isStream) {
     d(printf("mp3: pause\n"))
-#ifndef BROKEN_PCM
-    DeviceFreeze();
-#endif
+    if(output) output->Pause();
     SetPlayMode(pmPaused);
     }
 }
@@ -1872,9 +1906,7 @@ void cMP3Player::Play(void)
   if(playMode!=pmPlay) {
     d(printf("mp3: play\n"))
     if(playMode==pmStopped) state=msStart;
-#ifndef BROKEN_PCM
-    DevicePlay();
-#endif
+    if(output) output->Play();
     SetPlayMode(pmPlay);
     }
   Unlock();
